toMap method
A versioned, lossless projection including fitted passages and citations. Commit this with the corresponding store and embedding configuration.
Implementation
Map<String, Object?> toMap() => {
'version': 1,
'bundleId': bundleId,
'sources': sources,
'assets': assets,
'chunks': chunks.map((chunk) => chunk.toMap()).toList(),
'contextTexts': _contextTexts,
'inputRecoveries': _recoveries.map((r) => r.toMap()).toList(),
};